pub enum ConfigError {
Parse(String),
InvalidValue {
key: String,
message: String,
},
MissingExpiresOnOverride {
category: String,
},
Io(Error),
BoundaryParse(String),
}Expand description
Errors produced during configuration loading and validation.
Variants
Parse(String)
TOML parse failure.
InvalidValue
A config value is out of range or semantically invalid.
MissingExpiresOnOverride
A threshold override block is missing the mandatory expires field.
Io(Error)
I/O error reading a config file.
BoundaryParse(String)
YAML parse failure reading .sdivi/boundaries.yaml.